OC.L10N.register(
    "groupfolders",
    {
    "Access denied" : "Acces interzis",
    "Deny" : "Refuzați",
    "Allow" : "Permiteți",
    "Group" : "Grup",
    "Team" : "Echipă",
    "Read" : "Citeşte",
    "Create" : "Creează",
    "Delete" : "Șterge",
    "Share" : "Partajează",
    "You" : "Tu",
    "Add group" : "Adaugă grup",
    "Default" : "Implicită",
    "Unlimited" : "Nelimitată",
    "Folder name" : "Denumire director",
    "Quota" : "Procent",
    "Previous" : "Precedentul",
    "Next" : "Următorul",
    "User" : "Utilizator",
    "Unknown" : "Necunoscut",
    "None" : "Niciuna",
    "{size} used" : "{size} folosită",
    "Unset" : "Desetează"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
